@@ -1,9 +1,9 @@
-// $Id: color_general.hpp 3757 2015-11-30 12:03:07Z bradbell $
-# ifndef CPPAD_COLOR_GENERAL_HPP
-# define CPPAD_COLOR_GENERAL_HPP
+// $Id: color_general.hpp 3845 2016-11-19 01:50:47Z bradbell $
+# ifndef CPPAD_LOCAL_COLOR_GENERAL_HPP
+# define CPPAD_LOCAL_COLOR_GENERAL_HPP
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-16 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the
@@ -12,9 +12,11 @@ the terms of the
 A copy of this license is included in the COPYING file of this distribution.
 Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 -------------------------------------------------------------------------- */
+
+# include <cppad/configure.hpp>
 # include <cppad/local/cppad_colpack.hpp>
 
-namespace CppAD { // BEGIN_CPPAD_NAMESPACE
+namespace CppAD { namespace local { // BEGIN_CPPAD_LOCAL_NAMESPACE
 /*!
 \file color_general.hpp
 Coloring algorithm for a general sparse matrix.
@@ -44,9 +46,6 @@ add element \c e to set with index \c s.
 
 \param pattern [in]
 Is a representation of the sparsity pattern for the matrix.
-Note that color_general does not change the values in pattern,
-but it is not const because its iterator facility modifies some of its
-internal data.
 \n
 <code>m = pattern.n_set()</code>
 \n
@@ -58,15 +57,15 @@ All of the row indices are less than this value.
 sets \c n to the number of columns in the sparse matrix.
 All of the column indices are less than this value.
 \n
-<code>pattern.begin(i)</code>
-instructs the iterator facility to start iterating over
+<code>VectorSet::const_iterator itr(pattern, i)</code>
+constructs an iterator that starts iterating over
 columns in the i-th row of the sparsity pattern.
 \n
-<code>j = pattern.next_element()</code>
-Sets j to the next possibly non-zero column
-in the row specified by the previous call to <code>pattern.begin</code>.
-If there are no more such columns, the value
-<code>pattern.end()</code> is returned.
+<code>j = *itr</code>
+Sets j to the next possibly non-zero column.
+\n
+<code>++itr</code>
+Advances to the next possibly non-zero column.
 
 \param row [in]
 is a vector specifying which row indices to compute.
@@ -104,7 +103,7 @@ the maximum, with respct to k, of <code>color[ row[k] ]</code>
 */
 template <class VectorSet, class VectorSize>
 void color_general_cppad(
-	      VectorSet&        pattern ,
+	const VectorSet&        pattern ,
 	const VectorSize&       row     ,
 	const VectorSize&       col     ,
 	CppAD::vector<size_t>&  color   )
@@ -140,12 +139,12 @@ void color_general_cppad(
 	VectorSet not_appear;
 	not_appear.resize(n, m);
 	for(i = 0; i < m; i++)
-	{	pattern.begin(i);
-		j = pattern.next_element();
+	{	typename VectorSet::const_iterator pattern_itr(pattern, i);
+		j = *pattern_itr;
 		while( j != pattern.end() )
 		{	if( ! c2r_appear.is_element(j , i) )
 				not_appear.add_element(j, i);
-			j = pattern.next_element();
+			j = *(++pattern_itr);
 		}
 	}
 
@@ -179,19 +178,19 @@ void color_general_cppad(
 		// Forbid colors for which this row would destroy results:
 		//
 		// for each column that is non-zero for this row
-		pattern.begin(i);
-		j = pattern.next_element();
+		typename VectorSet::const_iterator pattern_itr(pattern, i);
+		j = *pattern_itr;
 		while( j != pattern.end() )
 		{	// for each row that appears with this column
-			c2r_appear.begin(j);
-			r = c2r_appear.next_element();
+			typename VectorSet::const_iterator c2r_itr(c2r_appear, j);
+			r = *c2r_itr;
 			while( r != c2r_appear.end() )
 			{	// if this is not the same row, forbid its color
 				if( (r < i) & (color[r] < m) )
 					forbidden[ color[r] ] = true;
-				r = c2r_appear.next_element();
+				r = *(++c2r_itr);
 			}
-			j = pattern.next_element();
+			j = *(++pattern_itr);
 		}
 
 
@@ -199,20 +198,20 @@ void color_general_cppad(
 		// Forbid colors that destroy results needed for this row.
 		//
 		// for each column that appears with this row
-		r2c_appear.begin(i);
-		j = r2c_appear.next_element();
+		typename VectorSet::const_iterator r2c_itr(r2c_appear, i);
+		j = *r2c_itr;
 		while( j != r2c_appear.end() )
 		{	// For each row that is non-zero for this column
 			// (the appear rows have already been checked above).
-			not_appear.begin(j);
-			r = not_appear.next_element();
+			typename VectorSet::const_iterator not_itr(not_appear, j);
+			r = *not_itr;
 			while( r != not_appear.end() )
 			{	// if this is not the same row, forbid its color
 				if( (r < i) & (color[r] < m) )
 					forbidden[ color[r] ] = true;
-				r = not_appear.next_element();
+				r = *(++not_itr);
 			}
-			j = r2c_appear.next_element();
+			j = *(++r2c_itr);
 		}
 
 		// pick the color with smallest index
@@ -235,7 +234,7 @@ can be computed together.
 */
 template <class VectorSet, class VectorSize>
 void color_general_colpack(
-	      VectorSet&        pattern ,
+	const VectorSet&        pattern ,
 	const VectorSize&       row     ,
 	const VectorSize&       col     ,
 	CppAD::vector<size_t>&  color   )
@@ -248,11 +247,11 @@ void color_general_colpack(
 	size_t n_nonzero_total = 0;
 	for(i = 0; i < m; i++)
 	{	n_nonzero[i] = 0;
-		pattern.begin(i);
-		j = pattern.next_element();
+		typename VectorSet::const_iterator pattern_itr(pattern, i);
+		j = *pattern_itr;
 		while( j != pattern.end() )
 		{	n_nonzero[i]++;
-			j = pattern.next_element();
+			j = *(++pattern_itr);
 		}
 		n_nonzero_total += n_nonzero[i];
 	}
@@ -264,12 +263,12 @@ void color_general_colpack(
 	for(i = 0; i < m; i++)
 	{	adolc_pattern[i]    = adolc_memory.data() + i_memory;
 		adolc_pattern[i][0] = n_nonzero[i];
-		pattern.begin(i);
-		j = pattern.next_element();
+		typename VectorSet::const_iterator pattern_itr(pattern, i);
+		j = *pattern_itr;
 		k = 1;
 		while(j != pattern.end() )
 		{	adolc_pattern[i][k++] = j;
-			j = pattern.next_element();
+			j = *(++pattern_itr);
 		}
 		CPPAD_ASSERT_UNKNOWN( k == 1 + n_nonzero[i] );
 		i_memory += k;
@@ -284,5 +283,5 @@ void color_general_colpack(
 }
 # endif // CPPAD_HAS_COLPACK
 
-} // END_CPPAD_NAMESPACE
+} } // END_CPPAD_LOCAL_NAMESPACE
 # endif
