@@ -1,9 +1,9 @@
-// $Id: discrete_op.hpp 3757 2015-11-30 12:03:07Z bradbell $
-# ifndef CPPAD_DISCRETE_OP_HPP
-# define CPPAD_DISCRETE_OP_HPP
+// $Id: discrete_op.hpp 3845 2016-11-19 01:50:47Z bradbell $
+# ifndef CPPAD_LOCAL_DISCRETE_OP_HPP
+# define CPPAD_LOCAL_DISCRETE_OP_HPP
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-16 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the
@@ -14,7 +14,7 @@ Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 -------------------------------------------------------------------------- */
 
 
-namespace CppAD { // BEGIN_CPPAD_NAMESPACE
+namespace CppAD { namespace local { // BEGIN_CPPAD_LOCAL_NAMESPACE
 /*!
 \file discrete_op.hpp
 Forward mode for z = f(x) where f is piecewise constant.
@@ -118,5 +118,5 @@ inline void forward_dis_op(
 }
 
 
-} // END_CPPAD_NAMESPACE
+} } // END_CPPAD_LOCAL_NAMESPACE
 # endif
