@@ -1,9 +1,8 @@
-// $Id$
 # ifndef CPPAD_LOCAL_OPTIMIZE_GET_OP_INFO_HPP
 # define CPPAD_LOCAL_OPTIMIZE_GET_OP_INFO_HPP
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-16 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-17 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the
@@ -19,7 +18,7 @@ Create operator information tables
 
 # include <cppad/local/optimize/op_info.hpp>
 # include <cppad/local/optimize/match_op.hpp>
-# include <cppad/local/optimize/cskip_info.hpp>
+# include <cppad/local/optimize/cexp_info.hpp>
 # include <cppad/local/optimize/usage.hpp>
 
 // BEGIN_CPPAD_LOCAL_OPTIMIZE_NAMESPACE
@@ -90,7 +89,7 @@ inline void usage_cexp_parent2arg(
 	size_t                  i_parent   ,
 	size_t                  i_arg      ,
 	vector<struct_op_info>& op_info    ,
-	sparse_pack&            cexp_set   )
+	sparse_list&            cexp_set   )
 {
 	// cexp_set
 	if( cexp_set.n_set() > 0 )
@@ -124,8 +123,8 @@ using AD< \a Base > and computations by this routine are done using type
 \a Base.
 
 \param conditional_skip
-If conditional_skip this is true, the conditional skip information
-cskip_info will be calculated.
+If conditional_skip this is true, the conditional expression information
+cexp_info will be calculated.
 This may be time intensive and may not have much benefit in the optimized
 recording.
 
@@ -157,16 +156,16 @@ This is only true for the primary variables.
 If the index i_var corresponds to an auxillary variable, var2op[i_var]
 is equalt to num_op (which is not a valid operator index).
 
-\param cskip_info
+\param cexp_info
 The input size of this vector must be zero.
-If conditional_skip is false, cskip_info is not changed.
+If conditional_skip is false, cexp_info is not changed.
 Otherwise,
-upon return cskip_info has size equal to the number of conditional expressions
+upon return cexp_info has size equal to the number of conditional expressions
 in the operation sequence; i.e., the number of CExpOp operators.
-The value cskip_info[j] is the information corresponding to the j-th
+The value cexp_info[j] is the information corresponding to the j-th
 conditional expression in the operation sequence.
 This vector is in the same order as the operation sequence; i.e.
-if j1 > j2, cskip_info[j1].i_op > cskip_info[j2].i_op.
+if j1 > j2, cexp_info[j1].i_op > cexp_info[j2].i_op.
 
 \param vecad_used
 The input size of this vector must be zero.
@@ -192,12 +191,12 @@ void get_op_info(
 	player<Base>*                 play                ,
 	const vector<size_t>&         dep_taddr           ,
 	vector<addr_t>&               var2op              ,
-	vector<struct_cskip_info>&    cskip_info          ,
+	vector<struct_cexp_info>&     cexp_info           ,
 	vector<bool>&                 vecad_used          ,
 	vector<struct_op_info>&       op_info             )
 {
 	CPPAD_ASSERT_UNKNOWN( var2op.size()  == 0 );
-	CPPAD_ASSERT_UNKNOWN( cskip_info.size() == 0 );
+	CPPAD_ASSERT_UNKNOWN( cexp_info.size() == 0 );
 	CPPAD_ASSERT_UNKNOWN( vecad_used.size() == 0 );
 	CPPAD_ASSERT_UNKNOWN( op_info.size() == 0 );
 
@@ -346,7 +345,7 @@ void get_op_info(
 	// comparisons results in the set holds. A set for operator i_op is
 	// not defined and left empty when op_info[i_op].usage = no_usage.
 	/// It is also left empty for the result of any VecAD operations.
-	sparse_pack cexp_set;
+	sparse_list cexp_set;
 	//
 	// number of sets
 	size_t num_set = 0;
@@ -471,38 +470,59 @@ void get_op_info(
 			CPPAD_ASSERT_UNKNOWN( NumRes(op) > 0 );
 			if( use_result != no_usage )
 			{	CPPAD_ASSERT_UNKNOWN( NumArg(CExpOp) == 6 );
-				addr_t mask[] = {1, 2, 4, 8};
-				for(size_t i = 0; i < 4; i++)
-				{	if( arg[1] & mask[i] )
-					{	size_t j_op = var2op[ arg[2 + i] ];
-						usage_cexp_parent2arg(
-							sum_op, i_op, j_op, op_info, cexp_set
-						);
-					}
+				// propgate from parent to left argument
+				if( arg[1] & 1 )
+				{	size_t j_op = var2op[ arg[2] ];
+					usage_cexp_parent2arg(
+						sum_op, i_op, j_op, op_info, cexp_set
+					);
 				}
-				// here is where we add elements to cexp_set
-				if( conditional_skip )
-				{	bool same_variable = bool(arg[1] & 4) && bool(arg[1] & 8);
-					same_variable     &= arg[4] == arg[5];
-					if( ( arg[1] & 4 ) && (! same_variable) )
-					{	// arg[4] is a variable
-						size_t j_op = var2op[ arg[4] ];
-						CPPAD_ASSERT_UNKNOWN(op_info[j_op].usage != no_usage);
-						// j_op corresponds to  the value used when the
+				// propgate from parent to right argument
+				if( arg[1] & 2 )
+				{	size_t j_op = var2op[ arg[3] ];
+					usage_cexp_parent2arg(
+							sum_op, i_op, j_op, op_info, cexp_set
+					);
+				}
+				// are if_true and if_false cases the same variable
+				bool same_variable = bool(arg[1] & 4) && bool(arg[1] & 8);
+				same_variable     &= arg[4] == arg[5];
+				//
+				// if_true
+				if( arg[1] & 4 )
+				{	size_t j_op = var2op[ arg[4] ];
+					bool can_skip = conditional_skip & (! same_variable);
+					can_skip     &= op_info[j_op].usage == no_usage;
+					usage_cexp_parent2arg(
+						sum_op, i_op, j_op, op_info, cexp_set
+					);
+					if( can_skip )
+					{	// j_op corresponds to the value used when the
 						// comparison result is true. It can be skipped when
 						// the comparison is false (0).
 						size_t element = 2 * cexp_index + 0;
 						cexp_set.add_element(j_op, element);
+						//
+						op_info[j_op].usage = yes_usage;
 					}
-					if( ( arg[1] & 8 ) && (! same_variable) )
-					{	// arg[5] is a variable
-						size_t j_op = var2op[ arg[5] ];
-						CPPAD_ASSERT_UNKNOWN(op_info[j_op].usage != no_usage);
-						// j_op corresponds to the value used when the
+				}
+				//
+				// if_false
+				if( arg[1] & 8 )
+				{	size_t j_op = var2op[ arg[5] ];
+					bool can_skip = conditional_skip & (! same_variable);
+					can_skip     &= op_info[j_op].usage == no_usage;
+					usage_cexp_parent2arg(
+						sum_op, i_op, j_op, op_info, cexp_set
+					);
+					if( can_skip )
+					{	// j_op corresponds to the value used when the
 						// comparison result is false. It can be skipped when
-						// the comparison is true (1).
+						// the comparison is true (0).
 						size_t element = 2 * cexp_index + 1;
 						cexp_set.add_element(j_op, element);
+						//
+						op_info[j_op].usage = yes_usage;
 					}
 				}
 			}
@@ -642,7 +662,7 @@ void get_op_info(
 			break; // -----------------------------------------------------
 
 			// =============================================================
-			// cumuilative summation operator
+			// cumulative summation operator
 			// ============================================================
 			case CSumOp:
 			CPPAD_ASSERT_UNKNOWN( NumRes(op) == 1 );
@@ -678,7 +698,7 @@ void get_op_info(
 				CPPAD_ASSERT_UNKNOWN(op_info[last_user_i_op].usage==no_usage);
 # ifndef NDEBUG
 				if( cexp_set.n_set() > 0 )
-				{	sparse_pack_const_iterator itr(cexp_set, last_user_i_op);
+				{	sparse_list_const_iterator itr(cexp_set, last_user_i_op);
 					CPPAD_ASSERT_UNKNOWN( *itr == cexp_set.end() );
 				}
 # endif
@@ -984,13 +1004,13 @@ void get_op_info(
 		}
 	}
 	// ----------------------------------------------------------------------
-	// compute cskip_info
+	// compute cexp_info
 	// ----------------------------------------------------------------------
 	if( cexp_set.n_set() == 0 )
 		return;
 	//
 	// initialize information for each conditional expression
-	cskip_info.resize(num_cexp_op);
+	cexp_info.resize(num_cexp_op);
 	for(size_t i = 0; i < num_cexp_op; i++)
 	{	CPPAD_ASSERT_UNKNOWN(
 			op_info[i].previous == 0 || op_info[i].usage == yes_usage
@@ -999,7 +1019,7 @@ void get_op_info(
 		arg             = op_info[i_op].arg;
 		CPPAD_ASSERT_UNKNOWN( op_info[i_op].op == CExpOp );
 		//
-		struct_cskip_info info;
+		struct_cexp_info info;
 		info.i_op       = i_op;
 		info.cop        = CompareOp( arg[0] );
 		info.flag       = arg[1];
@@ -1015,7 +1035,7 @@ void get_op_info(
 		CPPAD_ASSERT_UNKNOWN( index > 0 );
 		info.max_left_right = index;
 		//
-		cskip_info[i] = info;
+		cexp_info[i] = info;
 	};
 	// Determine which operators can be conditionally skipped
 	i_op = 0;
@@ -1025,7 +1045,7 @@ void get_op_info(
 		keep     &= op_info[i_op].usage != csum_usage;
 		keep     &= op_info[i_op].previous == 0;
 		if( keep )
-		{	sparse_pack_const_iterator itr(cexp_set, i_op);
+		{	sparse_list_const_iterator itr(cexp_set, i_op);
 			if( *itr != cexp_set.end() )
 			{	if( op_info[i_op].op == UserOp )
 				{	// i_op is the first operations in this user atomic call.
@@ -1051,14 +1071,14 @@ void get_op_info(
 				size_t index   = element / 2;
 				bool   compare = bool( element % 2 );
 				if( compare == false )
-				{	cskip_info[index].skip_op_false.push_back(i_op);
+				{	cexp_info[index].skip_op_false.push_back(i_op);
 					if( j_op != i_op )
-						cskip_info[index].skip_op_false.push_back(j_op);
+						cexp_info[index].skip_op_false.push_back(j_op);
 				}
 				else
-				{	cskip_info[index].skip_op_true.push_back(i_op);
+				{	cexp_info[index].skip_op_true.push_back(i_op);
 					if( j_op != i_op )
-						cskip_info[index].skip_op_true.push_back(j_op);
+						cexp_info[index].skip_op_true.push_back(j_op);
 				}
 				++itr;
 			}
