@@ -1,9 +1,9 @@
-// $Id: sinh_op.hpp 3757 2015-11-30 12:03:07Z bradbell $
-# ifndef CPPAD_SINH_OP_HPP
-# define CPPAD_SINH_OP_HPP
+// $Id: sinh_op.hpp 3845 2016-11-19 01:50:47Z bradbell $
+# ifndef CPPAD_LOCAL_SINH_OP_HPP
+# define CPPAD_LOCAL_SINH_OP_HPP
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-16 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the
@@ -14,7 +14,7 @@ Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 -------------------------------------------------------------------------- */
 
 
-namespace CppAD { // BEGIN_CPPAD_NAMESPACE
+namespace CppAD { namespace local { // BEGIN_CPPAD_LOCAL_NAMESPACE
 /*!
 \file sinh_op.hpp
 Forward and reverse mode calculations for z = sinh(x).
@@ -236,5 +236,5 @@ inline void reverse_sinh_op(
 	px[0] += azmul(pc[0], s[0]);
 }
 
-} // END_CPPAD_NAMESPACE
+} } // END_CPPAD_LOCAL_NAMESPACE
 # endif
