@@ -1,9 +1,9 @@
-// $Id: sqrt_op.hpp 3757 2015-11-30 12:03:07Z bradbell $
-# ifndef CPPAD_SQRT_OP_HPP
-# define CPPAD_SQRT_OP_HPP
+// $Id: sqrt_op.hpp 3845 2016-11-19 01:50:47Z bradbell $
+# ifndef CPPAD_LOCAL_SQRT_OP_HPP
+# define CPPAD_LOCAL_SQRT_OP_HPP
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-16 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the
@@ -14,7 +14,7 @@ Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 -------------------------------------------------------------------------- */
 
 
-namespace CppAD { // BEGIN_CPPAD_NAMESPACE
+namespace CppAD { namespace local { // BEGIN_CPPAD_LOCAL_NAMESPACE
 /*!
 \file sqrt_op.hpp
 Forward and reverse mode calculations for z = sqrt(x).
@@ -190,5 +190,5 @@ inline void reverse_sqrt_op(
 	px[0] += azmul(pz[0], inv_z0) / Base(2);
 }
 
-} // END_CPPAD_NAMESPACE
+} } // END_CPPAD_LOCAL_NAMESPACE
 # endif
