@@ -47,7 +47,8 @@ var list_down1 = [
 'cppad_vector.xml',
 'thread_alloc.xml',
 'index_sort.xml',
-'to_string.xml'
+'to_string.xml',
+'set_union.xml'
 ];
 var list_down0 = [
 'check_simple_vector.cpp.xml'
