@@ -18,7 +18,7 @@ var list_down3 = [
 'adfun.xml',
 'preprocessor.xml',
 'multi_thread.xml',
-'library.xml',
+'utility.xml',
 'ipopt_solve.xml',
 'example.xml',
 'speed.xml',
@@ -29,11 +29,12 @@ var list_down2 = [
 'theory.xml',
 'glossary.xml',
 'bib.xml',
-'bugs.xml',
-'wishlist.xml',
+'wish_list.xml',
 'whats_new.xml',
 'deprecated.xml',
 'compare_c.xml',
+'numeric_ad.xml',
+'addon.xml',
 'license.xml'
 ];
 var list_down1 = [
@@ -42,13 +43,13 @@ var list_down1 = [
 'reverse_identity.xml'
 ];
 var list_down0 = [
-'expforward.xml',
-'logforward.xml',
-'sqrtforward.xml',
-'sincosforward.xml',
-'atanforward.xml',
-'asinforward.xml',
-'acosforward.xml',
+'exp_forward.xml',
+'log_forward.xml',
+'sqrt_forward.xml',
+'sin_cos_forward.xml',
+'atan_forward.xml',
+'asin_forward.xml',
+'acos_forward.xml',
 'tan_forward.xml',
 'erf_forward.xml'
 ];
