@@ -58,6 +58,9 @@ var list_current0 = [
 'sparse_hessian.xml#x',
 'sparse_hessian.xml#w',
 'sparse_hessian.xml#p',
+'sparse_hessian.xml#p.Purpose',
+'sparse_hessian.xml#p.work',
+'sparse_hessian.xml#p.Column Subset',
 'sparse_hessian.xml#row, col',
 'sparse_hessian.xml#hes',
 'sparse_hessian.xml#work',
