@@ -1,6 +1,6 @@
-/* $Id: acos.cpp 3680 2015-05-07 19:17:37Z bradbell $ */
+// $Id: acos.cpp 3788 2016-02-09 15:50:06Z bradbell $
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-16 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the
@@ -20,7 +20,7 @@ $$
 $section The AD acos Function: Example and Test$$
 
 $code
-$verbatim%example/acos.cpp%0%// BEGIN C++%// END C++%1%$$
+$srcfile%example/acos.cpp%0%// BEGIN C++%// END C++%1%$$
 $$
 
 $end
