@@ -1,6 +1,6 @@
-// $Id: conj_grad.cpp 3757 2015-11-30 12:03:07Z bradbell $
+// $Id: conj_grad.cpp 3788 2016-02-09 15:50:06Z bradbell $
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-16 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the
@@ -91,7 +91,7 @@ goto Convergence Check.
 $lend
 
 $code
-$verbatim%example/conj_grad.cpp%0%// BEGIN C++%// END C++%1%$$
+$srcfile%example/conj_grad.cpp%0%// BEGIN C++%// END C++%1%$$
 $$
 
 $end
