@@ -1,6 +1,6 @@
-// $Id: cos.cpp 3757 2015-11-30 12:03:07Z bradbell $
+// $Id: cos.cpp 3856 2016-12-21 05:51:22Z bradbell $
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-16 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the
@@ -20,7 +20,7 @@ $section The AD cos Function: Example and Test$$
 
 
 $code
-$verbatim%example/cos.cpp%0%// BEGIN C++%// END C++%1%$$
+$srcfile%example/cos.cpp%0%// BEGIN C++%// END C++%1%$$
 $$
 
 $end
@@ -35,6 +35,7 @@ bool Cos(void)
 
 	using CppAD::AD;
 	using CppAD::NearEqual;
+	double eps99 = 99.0 * std::numeric_limits<double>::epsilon();
 
 	// domain space vector
 	size_t n  = 1;
@@ -55,7 +56,7 @@ bool Cos(void)
 
 	// check value
 	double check = std::cos(x0);
-	ok &= NearEqual(y[0] , check,  1e-10 , 1e-10);
+	ok &= NearEqual(y[0] , check, eps99, eps99);
 
 	// forward computation of first partial w.r.t. x[0]
 	CPPAD_TESTVECTOR(double) dx(n);
@@ -63,14 +64,14 @@ bool Cos(void)
 	dx[0] = 1.;
 	dy    = f.Forward(1, dx);
 	check = - std::sin(x0);
-	ok   &= NearEqual(dy[0], check, 1e-10, 1e-10);
+	ok   &= NearEqual(dy[0], check, eps99, eps99);
 
 	// reverse computation of derivative of y[0]
 	CPPAD_TESTVECTOR(double)  w(m);
 	CPPAD_TESTVECTOR(double) dw(n);
 	w[0]  = 1.;
 	dw    = f.Reverse(1, w);
-	ok   &= NearEqual(dw[0], check, 1e-10, 1e-10);
+	ok   &= NearEqual(dw[0], check, eps99, eps99);
 
 	// use a VecAD<Base>::reference object with cos
 	CppAD::VecAD<double> v(1);
@@ -78,7 +79,7 @@ bool Cos(void)
 	v[zero]           = x0;
 	AD<double> result = CppAD::cos(v[zero]);
 	check = std::cos(x0);
-	ok   &= NearEqual(result, check, 1e-10, 1e-10);
+	ok   &= NearEqual(result, check, eps99, eps99);
 
 	return ok;
 }
