@@ -1,6 +1,6 @@
-// $Id: div_eq.cpp 3757 2015-11-30 12:03:07Z bradbell $
+// $Id: div_eq.cpp 3856 2016-12-21 05:51:22Z bradbell $
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-16 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the
@@ -19,7 +19,7 @@ $mindex /= divide assign plus add$$
 
 
 $code
-$verbatim%example/div_eq.cpp%0%// BEGIN C++%// END C++%1%$$
+$srcfile%example/div_eq.cpp%0%// BEGIN C++%// END C++%1%$$
 $$
 
 $end
@@ -31,6 +31,7 @@ bool DivEq(void)
 {	bool ok = true;
 	using CppAD::AD;
 	using CppAD::NearEqual;
+	double eps99 = 99.0 * std::numeric_limits<double>::epsilon();
 
 	// domain space vector
 	size_t  n = 1;
@@ -53,16 +54,16 @@ bool DivEq(void)
 	CppAD::ADFun<double> f(x, y);
 
 	// check value
-	ok &= NearEqual(y[0] , x0*x0/(2.*4.*x0),  1e-10 , 1e-10);
-	ok &= NearEqual(y[1] ,             y[0],  1e-10 , 1e-10);
+	ok &= NearEqual(y[0] , x0*x0/(2.*4.*x0), eps99, eps99);
+	ok &= NearEqual(y[1] ,             y[0], eps99, eps99);
 
 	// forward computation of partials w.r.t. x[0]
 	CPPAD_TESTVECTOR(double) dx(n);
 	CPPAD_TESTVECTOR(double) dy(m);
 	dx[0] = 1.;
 	dy    = f.Forward(1, dx);
-	ok   &= NearEqual(dy[0], 1./8., 1e-10, 1e-10);
-	ok   &= NearEqual(dy[1], 1./8., 1e-10, 1e-10);
+	ok   &= NearEqual(dy[0], 1./8., eps99, eps99);
+	ok   &= NearEqual(dy[1], 1./8., eps99, eps99);
 
 	// reverse computation of derivative of y[0]
 	CPPAD_TESTVECTOR(double)  w(m);
@@ -70,7 +71,7 @@ bool DivEq(void)
 	w[0]  = 1.;
 	w[1]  = 0.;
 	dw    = f.Reverse(1, w);
-	ok   &= NearEqual(dw[0], 1./8., 1e-10, 1e-10);
+	ok   &= NearEqual(dw[0], 1./8., eps99, eps99);
 
 	// use a VecAD<Base>::reference object with computed division
 	CppAD::VecAD<double> v(1);
