@@ -1,6 +1,6 @@
-/* $Id: exp.cpp 3683 2015-05-10 02:24:16Z bradbell $ */
+// $Id: exp.cpp 3788 2016-02-09 15:50:06Z bradbell $
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-16 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the
@@ -19,7 +19,7 @@ $$
 $section The AD exp Function: Example and Test$$
 
 $code
-$verbatim%example/exp.cpp%0%// BEGIN C++%// END C++%1%$$
+$srcfile%example/exp.cpp%0%// BEGIN C++%// END C++%1%$$
 $$
 
 $end
