@@ -1,6 +1,6 @@
-// $Id: for_two.cpp 3757 2015-11-30 12:03:07Z bradbell $
+// $Id: for_two.cpp 3856 2016-12-21 05:51:22Z bradbell $
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-16 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the
@@ -21,7 +21,7 @@ $mindex partial$$
 
 
 $code
-$verbatim%example/for_two.cpp%0%// BEGIN C++%// END C++%1%$$
+$srcfile%example/for_two.cpp%0%// BEGIN C++%// END C++%1%$$
 $$
 
 $end
@@ -36,6 +36,7 @@ bool ForTwoCases()
 {	bool ok = true;
 	using CppAD::AD;
 	using CppAD::NearEqual;
+	double eps99 = 99.0 * std::numeric_limits<double>::epsilon();
 	using CppAD::exp;
 	using CppAD::sin;
 	using CppAD::cos;
@@ -84,14 +85,14 @@ bool ForTwoCases()
 	[ 2 * x[0] * cos(x[1]) ]
 	*/
 	// second partial of y w.r.t x[0] and x[1]
-	ok &=  NearEqual( 2.*exp(x[1]), ddy[0*p+0], 1e-10, 1e-10 );
-	ok &=  NearEqual( 2.*sin(x[1]), ddy[1*p+0], 1e-10, 1e-10 );
-	ok &=  NearEqual( 2.*cos(x[1]), ddy[2*p+0], 1e-10, 1e-10 );
+	ok &=  NearEqual( 2.*exp(x[1]), ddy[0*p+0], eps99, eps99);
+	ok &=  NearEqual( 2.*sin(x[1]), ddy[1*p+0], eps99, eps99);
+	ok &=  NearEqual( 2.*cos(x[1]), ddy[2*p+0], eps99, eps99);
 
 	// second partial of F w.r.t x[0] and x[1]
-	ok &=  NearEqual( 2.*x[0]*exp(x[1]), ddy[0*p+1], 1e-10, 1e-10 );
-	ok &=  NearEqual( 2.*x[0]*cos(x[1]), ddy[1*p+1], 1e-10, 1e-10 );
-	ok &=  NearEqual(-2.*x[0]*sin(x[1]), ddy[2*p+1], 1e-10, 1e-10 );
+	ok &=  NearEqual( 2.*x[0]*exp(x[1]), ddy[0*p+1], eps99, eps99);
+	ok &=  NearEqual( 2.*x[0]*cos(x[1]), ddy[1*p+1], eps99, eps99);
+	ok &=  NearEqual(-2.*x[0]*sin(x[1]), ddy[2*p+1], eps99, eps99);
 
 	return ok;
 }
