@@ -1,6 +1,6 @@
-// $Id: interp_retape.cpp 3757 2015-11-30 12:03:07Z bradbell $
+// $Id: interp_retape.cpp 3856 2016-12-21 05:51:22Z bradbell $
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-16 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the
@@ -28,7 +28,7 @@ $pre
 
 $$
 $code
-$verbatim%example/interp_retape.cpp%0%// BEGIN C++%// END C++%1%$$
+$srcfile%example/interp_retape.cpp%0%// BEGIN C++%// END C++%1%$$
 $$
 
 $end
@@ -88,6 +88,7 @@ bool interp_retape(void)
 
 	using CppAD::AD;
 	using CppAD::NearEqual;
+	double eps99 = 99.0 * std::numeric_limits<double>::epsilon();
 
 	// domain space vector
 	size_t n = 1;
@@ -130,7 +131,7 @@ bool interp_retape(void)
 		delta  = ArgumentValue[k+1] - ArgumentValue[k];
 		check  = FunctionValue[k+1] * (x[0]-ArgumentValue[k]) / delta
 	               + FunctionValue[k] * (ArgumentValue[k+1]-x[0]) / delta;
-		ok    &= NearEqual(Y[0], check, 1e-10, 1e-10);
+		ok    &= NearEqual(Y[0], check, eps99, eps99);
 
 		// evaluate partials w.r.t. x[0]
 		dx[0] = 1.;
@@ -139,7 +140,7 @@ bool interp_retape(void)
 		// check that the derivative is the slope
 		check = (FunctionValue[k+1] - FunctionValue[k])
 		      / (ArgumentValue[k+1] - ArgumentValue[k]);
-		ok   &= NearEqual(dy[0], check, 1e-10, 1e-10);
+		ok   &= NearEqual(dy[0], check, eps99, eps99);
 	}
 	return ok;
 }
