@@ -1,6 +1,6 @@
-/* $Id: mul_level.cpp 3735 2015-10-01 13:43:46Z bradbell $ */
+// $Id: mul_level.cpp 3788 2016-02-09 15:50:06Z bradbell $
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-16 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the
@@ -49,7 +49,7 @@ Adolc's type $code adouble$$ and CppAD's type $code AD<adouble>$$.
 
 $head Source$$
 $code
-$verbatim%example/mul_level.cpp%0%// BEGIN C++%// END C++%1%$$
+$srcfile%example/mul_level.cpp%0%// BEGIN C++%// END C++%1%$$
 $$
 
 $end
