@@ -1,6 +1,6 @@
-// $Id: ode_stiff.cpp 3757 2015-11-30 12:03:07Z bradbell $
+// $Id: ode_stiff.cpp 3788 2016-02-09 15:50:06Z bradbell $
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-16 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the
@@ -41,7 +41,7 @@ x_1 (t)    & = & a_0 [ \exp( - a_1 t ) - \exp( - a_0 t ) ] / ( a_0 - a_1 )
 The example tests Rosen34 using the relations above:
 
 $code
-$verbatim%example/ode_stiff.cpp%0%// BEGIN C++%// END C++%1%$$
+$srcfile%example/ode_stiff.cpp%0%// BEGIN C++%// END C++%1%$$
 $$
 
 $end
