@@ -1,6 +1,6 @@
-// $Id: sub.cpp 3757 2015-11-30 12:03:07Z bradbell $
+// $Id: sub.cpp 3856 2016-12-21 05:51:22Z bradbell $
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-16 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the
@@ -18,7 +18,7 @@ $mindex - subtract minus$$
 
 
 $code
-$verbatim%example/sub.cpp%0%// BEGIN C++%// END C++%1%$$
+$srcfile%example/sub.cpp%0%// BEGIN C++%// END C++%1%$$
 $$
 
 $end
@@ -30,6 +30,7 @@ bool Sub(void)
 {	bool ok = true;
 	using CppAD::AD;
 	using CppAD::NearEqual;
+	double eps99 = 99.0 * std::numeric_limits<double>::epsilon();
 
 	// domain space vector
 	size_t  n =  1;
@@ -54,21 +55,21 @@ bool Sub(void)
 	CppAD::ADFun<double> f(x, y);
 
 	// check value
-	ok &= NearEqual(y[0], x0-4.+3.+2.-2.*x0+1.,  1e-10 , 1e-10);
+	ok &= NearEqual(y[0], x0-4.+3.+2.-2.*x0+1., eps99, eps99);
 
 	// forward computation of partials w.r.t. x[0]
 	CPPAD_TESTVECTOR(double) dx(n);
 	CPPAD_TESTVECTOR(double) dy(m);
 	dx[0] = 1.;
 	dy    = f.Forward(1, dx);
-	ok   &= NearEqual(dy[0], -1., 1e-10, 1e-10);
+	ok   &= NearEqual(dy[0], -1., eps99, eps99);
 
 	// reverse computation of derivative of y[0]
 	CPPAD_TESTVECTOR(double)  w(m);
 	CPPAD_TESTVECTOR(double) dw(n);
 	w[0]  = 1.;
 	dw    = f.Reverse(1, w);
-	ok   &= NearEqual(dw[0], -1., 1e-10, 1e-10);
+	ok   &= NearEqual(dw[0], -1., eps99, eps99);
 
 	// use a VecAD<Base>::reference object with subtraction
 	CppAD::VecAD<double> v(1);
