@@ -1,6 +1,6 @@
-// $Id: exp_2_for0.cpp 3757 2015-11-30 12:03:07Z bradbell $
+// $Id: exp_2_for0.cpp 3788 2016-02-09 15:50:06Z bradbell $
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-16 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the
@@ -24,7 +24,7 @@ $mindex exp_2$$
 
 
 
-$codep */
+$srccode%cpp% */
 # include <cmath>            // for fabs function
 bool exp_2_for0(double *v0)  // double v0[6]
 {	bool  ok = true;
@@ -51,6 +51,6 @@ bool exp_2_for0(void)
 {	double v0[6];
 	return exp_2_for0(v0);
 }
-/* $$
+/* %$$
 $end
 */
