@@ -1,6 +1,6 @@
-// $Id: exp_2_for1.cpp 3757 2015-11-30 12:03:07Z bradbell $
+// $Id: exp_2_for1.cpp 3788 2016-02-09 15:50:06Z bradbell $
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-16 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the
@@ -23,7 +23,7 @@ $section exp_2: Verify First Order Forward Sweep$$
 $mindex exp_2$$
 
 
-$codep */
+$srccode%cpp% */
 # include <cmath>                   // prototype for fabs
 extern bool exp_2_for0(double *v0); // computes zero order forward sweep
 bool exp_2_for1(double *v1)         // double v1[6]
@@ -54,6 +54,6 @@ bool exp_2_for1(void)
 {	double v1[6];
 	return exp_2_for1(v1);
 }
-/* $$
+/* %$$
 $end
 */
