@@ -1,6 +1,6 @@
-// $Id: harmonic_work.cpp 3757 2015-11-30 12:03:07Z bradbell $
+// $Id: harmonic_work.cpp 3788 2016-02-09 15:50:06Z bradbell $
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-16 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the
@@ -69,7 +69,7 @@ this function call will combine the results and return the final summation.
 
 $head Source$$
 $code
-$verbatim%multi_thread/harmonic_work.cpp%0%// BEGIN C++%// END C++%1%$$
+$srcfile%multi_thread/harmonic_work.cpp%0%// BEGIN C++%// END C++%1%$$
 $$
 
 
