@@ -1,6 +1,6 @@
-// $Id: multi_newton_time.cpp 3757 2015-11-30 12:03:07Z bradbell $
+// $Id: multi_newton_time.cpp 3788 2016-02-09 15:50:06Z bradbell $
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-16 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the
@@ -137,7 +137,7 @@ derivatives will be computed using a hand coded routine.
 
 $head Source$$
 $code
-$verbatim%multi_thread/multi_newton_time.cpp%0%// BEGIN C++%// END C++%1%$$
+$srcfile%multi_thread/multi_newton_time.cpp%0%// BEGIN C++%// END C++%1%$$
 $$
 
 $end
