@@ -1,6 +1,6 @@
-// $Id: sparse_jac_fun.cpp 3757 2015-11-30 12:03:07Z bradbell $
+// $Id: sparse_jac_fun.cpp 3788 2016-02-09 15:50:06Z bradbell $
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-16 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the
@@ -20,7 +20,7 @@ $section sparse_jac_fun: Example and test$$
 $mindex sparse_jac_fun$$
 
 $code
-$verbatim%speed/example/sparse_jac_fun.cpp%0%// BEGIN C++%// END C++%1%$$
+$srcfile%speed/example/sparse_jac_fun.cpp%0%// BEGIN C++%// END C++%1%$$
 $$
 
 $end
