@@ -1,6 +1,6 @@
-// $Id: mat_mul.cpp 3757 2015-11-30 12:03:07Z bradbell $
+// $Id: mat_mul.cpp 3794 2016-02-29 20:42:44Z bradbell $
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-16 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the
@@ -34,14 +34,15 @@ See $cref link_mat_mul$$.
 
 $head Implementation$$
 
-$codep */
+$srccode%cpp% */
 # include <Sacado.hpp>
 # include <cppad/utility/vector.hpp>
 # include <cppad/speed/mat_sum_sq.hpp>
 # include <cppad/speed/uniform_01.hpp>
 
 // list of possible options
-extern bool global_memory, global_onetape, global_atomic, global_optimize;
+# include <map>
+extern std::map<std::string, bool> global_option;
 
 bool link_mat_mul(
 	size_t                           size     ,
@@ -51,7 +52,7 @@ bool link_mat_mul(
 	CppAD::vector<double>&           dz       )
 {
 	// speed test global option values
-	if( global_memory || global_onetape || global_atomic || global_optimize )
+	if( global_option["memory"] || global_option["onetape"] || global_option["atomic"] || global_option["optimize"] )
 		return false;
 	// -----------------------------------------------------
 	// setup
@@ -96,6 +97,6 @@ bool link_mat_mul(
 	// ---------------------------------------------------------
 	return true;
 }
-/* $$
+/* %$$
 $end
 */
