@@ -1,6 +1,6 @@
-// $Id: ode.cpp 3757 2015-11-30 12:03:07Z bradbell $
+// $Id: ode.cpp 3794 2016-02-29 20:42:44Z bradbell $
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-16 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the
@@ -33,7 +33,7 @@ See $cref link_ode$$.
 
 $head Implementation$$
 
-$codep */
+$srccode%cpp% */
 # include <Sacado.hpp>
 // # include <algorithm>
 # include <cassert>
@@ -42,7 +42,8 @@ $codep */
 # include <cppad/speed/ode_evaluate.hpp>
 
 // list of possible options
-extern bool global_memory, global_onetape, global_atomic, global_optimize;
+# include <map>
+extern std::map<std::string, bool> global_option;
 
 bool link_ode(
 	size_t                     size       ,
@@ -52,9 +53,9 @@ bool link_ode(
 )
 {
 	// speed test global option values
-	if( global_atomic )
+	if( global_option["atomic"] )
 		return false;
-	if( global_memory || global_onetape || global_optimize )
+	if( global_option["memory"] || global_option["onetape"] || global_option["optimize"] )
 		return false;
 	// -------------------------------------------------------------
 	// setup
@@ -90,6 +91,6 @@ bool link_ode(
 	}
 	return true;
 }
-/* $$
+/* %$$
 $end
 */
