@@ -1,6 +1,6 @@
-// $Id: runge_45.cpp 3785 2016-02-08 12:53:06Z bradbell $
+// $Id: runge_45.cpp 3856 2016-12-21 05:51:22Z bradbell $
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-16 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the
@@ -50,6 +50,8 @@ bool Runge45(void)
 {	bool ok = true;
 
 	using namespace CppAD;
+	using CppAD::NearEqual;
+	double eps99 = 99.0 * std::numeric_limits<double>::epsilon();
 
 	size_t i;
 	size_t j;
@@ -90,14 +92,14 @@ bool Runge45(void)
 	// x[i](2) = exp( w[0] ) * (w[1] / 1) * ... * (w[i] / i) * 2^i
 	AD<double> xi2 = exp(w[0]);
 	for(i = 0; i < n-1; i++)
-	{	ok &= NearEqual(x[i],  xi2, 1e-14, 1e-14);
+	{	ok &= NearEqual(x[i],  xi2, eps99, eps99);
 		if( i < n-2 )
 			xi2 *= w[i+1] * 2. / double(i+1);
 	}
 
 	// x[n-1](2) = exp(2 * w[0]) * w[1] * 2^2 / 2
 	xi2 = exp(2. * w[0]) * w[1] * 2.;
-	ok &= NearEqual(x[n-1], xi2, 1e-14, 1e-14);
+	ok &= NearEqual(x[n-1], xi2, eps99, eps99);
 
 	// the partial of x[i](2) with respect to w[j] is
 	//	x[i](2) / w[j] if 0 < j <= i < n-1
@@ -116,11 +118,11 @@ bool Runge45(void)
 		for(j = 0; j < m; j++)
 		{	// check partial of x[i] w.r.t w[j]
 			if (j == 0 )
-				ok &= NearEqual(q[j], x[i], 1e-14, 1e-14);
+				ok &= NearEqual(q[j], x[i], eps99, eps99);
 			else if( j <= i  )
 				ok &= NearEqual(
 					q[j], x[i]/w[j], 1e-14, 1e-14);
-			else	ok &= NearEqual(q[j], 0., 1e-14, 1e-14);
+			else	ok &= NearEqual(q[j], 0., eps99, eps99);
 		}
 	}
 
@@ -134,11 +136,11 @@ bool Runge45(void)
 	for(j = 0; j < m; j++)
 	{	// check partial of x[n-1] w.r.t w[j]
 		if (j == 0 )
-			ok &= NearEqual(q[j], 2.*x[i], 1e-14, 1e-14);
+			ok &= NearEqual(q[j], 2.*x[i], eps99, eps99);
 		else if( j == 1  )
 			ok &= NearEqual(
 				q[j], x[i]/w[1], 1e-14, 1e-14);
-		else	ok &= NearEqual(q[j], 0., 1e-14, 1e-14);
+		else	ok &= NearEqual(q[j], 0., eps99, eps99);
 	}
 
 	return ok;
