@@ -1,6 +1,5 @@
-// $Id: test_more.cpp 3811 2016-03-27 13:00:39Z bradbell $
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-16 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-17 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the
@@ -31,6 +30,7 @@ extern bool assign(void);
 extern bool atan(void);
 extern bool atanh(void);
 extern bool atan2(void);
+extern bool atomic_sparsity(void);
 extern bool azmul(void);
 extern bool base_adolc(void);
 extern bool base_alloc_test(void);
@@ -167,6 +167,7 @@ int main(void)
 	ok &= Run( atan,            "atan"           );
 	ok &= Run( atanh,           "atanh"          );
 	ok &= Run( atan2,           "atan2"          );
+	ok &= Run( atomic_sparsity, "atomic_sparsity");
 	ok &= Run( azmul,           "azmul"          );
 	ok &= Run( check_simple_vector, "check_simple_vector" );
 	ok &= Run( checkpoint,      "checkpoint"     );
